# djc
Command Line Interface for Django with Nifty Scripts

# usage
Install djc in the same environment as your Django project
## create a new user
```bash
djc create-user --project="$PWD/test/mysite" --username="daniel" --email="example@gmail.com" --password="password" --debug="true"
```
